@@ -1,23 +1,27 @@
-/* Clearlooks Gummy style
- * Copyright (C) 2007 Andrea Cimitan
+/* Clearlooks - a cairo based GTK+ engine
+ * Copyright (C) 2007-2008 Andrea Cimitan <andrea.cimitan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Project contact: <gnome-themes-list@gnome.org>
+ *
+ *
+ * This file defines the Clearlooks Gummy style
  *
- * Written by Andrea Cimitan <andrea.cimitan@gmail.com>
  */
+ 
 
 #include "clearlooks_draw.h"
 #include "clearlooks_style.h"
@@ -181,7 +185,7 @@ clearlooks_gummy_draw_button (cairo_t                *cr,
 			cairo_stroke (cr);
 		}
 
-		if (params->is_default)
+		if (params->is_default && !params->disabled)
 		{
 			CairoColor shadow = colors->spot[1];
 
@@ -1443,11 +1447,13 @@ clearlooks_gummy_draw_radiobutton (cairo_t                  *cr,
 	{
 		if (inconsistent)
 		{
-			cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
-			cairo_set_line_width (cr, ceil (radius * 2 / 3));
+			gdouble line_width = floor (radius * 2 / 3);
 
-			cairo_move_to (cr, ceil (cx - radius/3.0), ceil (cy));
-			cairo_line_to (cr, ceil (cx + radius/3.0), ceil (cy));
+			cairo_set_line_cap(cr, CAIRO_LINE_CAP_ROUND);
+			cairo_set_line_width (cr, line_width);
+
+			cairo_move_to (cr, ceil (cx - radius/3.0 - line_width) + line_width, ceil (cy - line_width) + line_width);
+			cairo_line_to (cr, floor (cx + radius/3.0 + line_width) - line_width, ceil (cy - line_width) + line_width);
 
 			ge_cairo_set_color (cr, dot);
 			cairo_stroke (cr);
@@ -1549,6 +1555,26 @@ clearlooks_gummy_draw_checkbox (cairo_t                  *cr,
 	}
 }
 
+static void
+clearlooks_gummy_draw_icon_view_item (cairo_t                *cr,
+	                                  const ClearlooksColors *colors,
+	                                  const WidgetParameters *params,
+	                                  int x, int y, int width, int height)
+{
+	CairoColor color;
+	gfloat radius;
+
+	if (params->focus)
+		color = colors->base[params->state_type];
+	else
+		color = colors->base[GTK_STATE_ACTIVE];
+
+	radius = MIN (width / 2, params->radius);
+	radius = MIN (height / 2, radius);
+
+	clearlooks_draw_gummy_gradient (cr, x, y, width, height, &color, params->disabled, params->radius, CR_CORNER_ALL);
+}
+
 static void
 clearlooks_gummy_draw_focus (cairo_t                *cr,
                              const ClearlooksColors *colors,
@@ -1634,6 +1660,8 @@ clearlooks_gummy_draw_focus (cairo_t                *cr,
 			break;
 		case CL_FOCUS_SCALE:
 			break;
+		case CL_FOCUS_ICONVIEW:
+			break;
 		case CL_FOCUS_UNKNOWN:
 			/* Fallback to classic function, dots */
 			clearlooks_draw_focus (cr, colors, widget, focus, x, y, width, height);
@@ -1701,6 +1729,7 @@ clearlooks_register_style_gummy (ClearlooksStyleFunctions *functions, Clearlooks
 	functions->draw_statusbar          = clearlooks_gummy_draw_statusbar;
 	functions->draw_checkbox           = clearlooks_gummy_draw_checkbox;
 	functions->draw_radiobutton        = clearlooks_gummy_draw_radiobutton;
+	functions->draw_icon_view_item     = clearlooks_gummy_draw_icon_view_item;
 	functions->draw_focus              = clearlooks_gummy_draw_focus;
 
 	constants->topleft_highlight_shade = 1.3;
